@@ -13,7 +13,7 @@ use Data::Record::Serialize::Error { errors =>
         sqlite_backend
    )] }, -all;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 use Data::Record::Serialize::Types -types;
 
@@ -84,6 +84,7 @@ has table => (
 
 
 
+
 has schema => (
     is        => 'ro',
     predicate => 1,
@@ -160,9 +161,15 @@ has _dbh => (
     is        => 'rwp',
     init_arg  => undef,
     clearer   => 1,
-    predicate => 1
+    predicate => 1,
 );
 
+
+
+
+
+
+
 has column_defs => (
     is       => 'rwp',
     lazy     => 1,
@@ -309,10 +316,11 @@ has _producer => (
 
 
 
+
 sub setup {
     my $self = shift;
 
-    return if $self->_dbh;
+    return if $self->_has_dbh;
 
     my %attr = (
         AutoCommit               => !$self->batch,
@@ -450,6 +458,8 @@ sub setup {
 sub flush {
     my $self = shift;
 
+    return 1 unless $self->_has_dbh;
+
     my $queue = $self->queue;
 
     if ( @{ $queue } ) {
@@ -541,12 +551,10 @@ after '_trigger_output_types' => sub {
 sub close {
     my $self = shift;
 
-    $self->flush
-      if $self->batch;
-
-    $self->_dbh->disconnect
-      if $self->_has_dbh;
+    return 1 unless $self->_has_dbh;
 
+    $self->flush if $self->batch;
+    $self->_dbh->disconnect;
     $self->_clear_dbh;
 
     1;
@@ -572,7 +580,6 @@ sub DEMOLISH {
     $self->_dbh->disconnect
       if  $self->_has_dbh;
 
-    $self->_clear_dbh;
 }
 
 
@@ -612,7 +619,7 @@ Data::Record::Serialize::Encode::dbi - store a record in a database
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -818,6 +825,9 @@ C<Data::Record::Serialize::Encode::dbi::queue> warning to silence it.
 
 =for Pod::Coverage has_schema
 
+=for Pod::Coverage _has_dbh
+  _clear_dbh
+
 =for Pod::Coverage setup
 
 =for Pod::Coverage say
